<?php

/*
Plugin Name: Sky Login Redirect
Plugin URI: https://utopique.net/products/sky-login-redirect-premium/
Description: Redirects users to the page they were prior to logging in or logging out. Features an awesome login customizer.
Version: 3.5.1
Author: Utopique Plugins
Author URI: https://utopique.net/
Copyright: (c) 2009-2021 Utopique Plugins
Text Domain: sky-login-redirect
License: GPLv2 or later
Requires at least: 3.0
Tested up to: 5.8
Requires PHP: 5.3
WC tested up to: 5.3
WC requires at least: 3.3
*/
namespace SkyLoginRedirect\Plugin;

if ( !defined( 'ABSPATH' ) ) {
    exit;
}
// current version
define( 'SLR_VERSION', '3.5.1' );
// FS

if ( function_exists( __NAMESPACE__ . '\\sky_login_redirect_fs' ) ) {
    sky_login_redirect_fs()->set_basename( false, __FILE__ );
} else {
    //FS
    
    if ( !function_exists( __NAMESPACE__ . '\\sky_login_redirect_fs' ) ) {
        // Create a helper function for easy SDK access.
        function sky_login_redirect_fs()
        {
            global  $sky_login_redirect_fs ;
            
            if ( !isset( $sky_login_redirect_fs ) ) {
                // Include Freemius SDK.
                require_once dirname( __FILE__ ) . '/freemius/start.php';
                $sky_login_redirect_fs = fs_dynamic_init( array(
                    'id'             => '3088',
                    'slug'           => 'sky-login-redirect',
                    'type'           => 'plugin',
                    'public_key'     => 'pk_f0e9c9d4e383120cf38d5b44b586b',
                    'is_premium'     => false,
                    'has_addons'     => false,
                    'has_paid_plans' => true,
                    'menu'           => array(
                    'slug' => 'sky-login-redirect',
                ),
                    'is_live'        => true,
                ) );
            }
            
            return $sky_login_redirect_fs;
        }
        
        // Init Freemius.
        sky_login_redirect_fs();
        // Signal that SDK was initiated.
        do_action( 'sky_login_redirect_fs_loaded' );
    }
    
    /**
     * Localization
     **/
    add_action( 'plugins_loaded', __NAMESPACE__ . '\\slr_load_plugin_textdomain' );
    function slr_load_plugin_textdomain()
    {
        load_plugin_textdomain( 'sky-login-redirect', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );
    }
    
    /**
     * Charge notre dépendance Carbon Fields via Composer
     */
    add_action( 'after_setup_theme', __NAMESPACE__ . '\\load_carbonfields' );
    function load_carbonfields()
    {
        require_once plugin_dir_path( __FILE__ ) . '/vendor/autoload.php';
        \Carbon_Fields\Carbon_Fields::boot();
    }
    
    /**
     * Charge notre fichier de plugin
     *
     * @return mixed
     */
    add_action( 'plugins_loaded', __NAMESPACE__ . '\\load_plugin' );
    function load_plugin()
    {
        require_once plugin_dir_path( __FILE__ ) . '/includes/options.php';
    }
    
    /**
     * Add settings link to plugins page
     **/
    $plugin = plugin_basename( __FILE__ );
    add_filter(
        "plugin_action_links_{$plugin}",
        __NAMESPACE__ . '\\slr_settings_link',
        10,
        1
    );
    function slr_settings_link( $links )
    {
        $settings_link = sprintf( '<a href="%s">%s</a>', esc_url( admin_url( 'admin.php?page=sky-login-redirect' ) ), __( 'Settings', 'sky-login-redirect' ) );
        array_unshift( $links, $settings_link );
        // or array_push
        return $links;
    }
    
    /**
     * Add additional useful links to plugins page
     **/
    add_filter(
        'plugin_row_meta',
        __NAMESPACE__ . '\\slr_row_meta',
        10,
        2
    );
    function slr_row_meta( $links, $file )
    {
        
        if ( $file === plugin_basename( __FILE__ ) ) {
            $row_meta = array(
                'docs'    => '<a href="' . esc_url( apply_filters( 'slr_docs_url', 'https://utopique.net/docs/' ) ) . '" title="' . esc_attr( __( 'View Documentation', 'sky-login-redirect' ) ) . '">' . __( 'Docs', 'sky-login-redirect' ) . '</a>',
                'support' => '<a href="' . esc_url( apply_filters( 'slr_support_url', 'https://wordpress.org/support/plugin/sky-login-redirect/' ) ) . '" title="' . esc_attr( __( 'Contact support', 'sky-login-redirect' ) ) . '">' . __( 'Support', 'sky-login-redirect' ) . '</a>',
                'rate'    => '<a href="' . esc_url( apply_filters( 'slr_rate', 'https://wordpress.org/support/plugin/sky-login-redirect/reviews/?rate=5#new-post' ) ) . '" target="_blank" title="' . esc_attr( __( 'Rate Sky Login Redirect', 'sky-login-redirect' ) ) . '">' . __( 'Rate us', 'sky-login-redirect' ) . '</a>',
            );
            return array_merge( $links, $row_meta );
        }
        
        return (array) $links;
    }
    
    /*
     * Notices
     */
    //add plugin activation time
    register_activation_hook( __FILE__, __NAMESPACE__ . '\\slr_activation_time' );
    function slr_activation_time()
    {
        $get_activation_time = strtotime( "now" );
        add_option( 'SLR_activation_time', $get_activation_time );
    }
    
    //1. add JS script to record dismiss action
    add_action( 'admin_enqueue_scripts', __NAMESPACE__ . '\\slr_add_notices_script' );
    function slr_add_notices_script()
    {
        wp_register_script(
            'slr-notice-update',
            plugins_url( 'lib/js/admin-notices.js', __FILE__ ),
            [ 'jquery' ],
            SLR_VERSION,
            true
        );
        wp_localize_script( 'slr-notice-update', 'notice_params', array(
            'ajaxurl' => get_admin_url() . 'admin-ajax.php',
        ) );
        wp_enqueue_script( 'slr-notice-update' );
    }
    
    // 2. record dismiss
    // action hook (wp_ajax_SLR_EOY_2020) must correspond to (wp_ajax_) + the action name in the JS file (SLR_EOY_2020)
    add_action( 'wp_ajax_SLR_EOY_2020', __NAMESPACE__ . '\\slr_dismiss_notice' );
    function slr_dismiss_notice()
    {
        update_option( 'SLR_EOY_2020', true );
    }
    
    // 3. check if notice should be shown or not
    add_action( 'admin_init', __NAMESPACE__ . '\\slr_check_installation_time' );
    function slr_check_installation_time()
    {
        $install_date = get_option( 'SLR_activation_time' );
        $past_date = strtotime( '-2 days' );
        if ( $past_date >= $install_date ) {
            // if no record set, display the notice
            if ( get_option( 'SLR_EOY_2020' ) != true ) {
                add_action( 'admin_notices', __NAMESPACE__ . '\\slr_EOY_admin_notice' );
            }
        }
    }
    
    // 4. notice
    function slr_EOY_admin_notice()
    {
        $current_screen = get_current_screen();
        $hook = $current_screen->id;
        $array = [
            'toplevel_page_sky-login-redirect',
            'login-redirect_page_sky-login-redirect-account',
            'login-redirect_page_sky-login-redirect-pricing',
            'plugins',
            'dashboard'
        ];
        $sky_login_redirect_fs = sky_login_redirect_fs();
        if ( in_array( $hook, $array ) && date( "Ymd" ) < '20210101' && ($sky_login_redirect_fs->is_not_paying() || $sky_login_redirect_fs->is_free_plan()) ) {
            // class name is important as it's detected by the JS script: EOY-2020
            echo  sprintf( '<div class="EOY-2020 notice notice-info is-dismissible"><p>' . __( 'End of year sale: save %s on', 'sky-login-redirect' ) . ' <a href="%s" target="_blank">Sky Login Redirect Premium</a>.</p></div>', '20%', esc_url( 'https://utopique.net/products/sky-login-redirect-premium/' ) ) ;
        }
    }
    
    /*
    * Admin credits.
    */
    add_filter( 'admin_footer_text', __NAMESPACE__ . '\\slr_admin_credits' );
    function slr_admin_credits( $footer_text )
    {
        $current_screen = get_current_screen();
        $hook = $current_screen->id;
        $array = [ 'toplevel_page_sky-login-redirect', 'login-redirect_page_sky-login-redirect-account', 'login-redirect_page_sky-login-redirect-contact' ];
        if ( !in_array( $hook, $array ) ) {
            return $footer_text;
        }
        $footer_text = sprintf( __( 'Thank you for using %s', 'sky-login-redirect' ), '<a href="https://utopique.net/products/sky-login-redirect-premium/" target="_blank">Sky Login Redirect</a>' );
        //$footer_text.= ' &bull; ' . sprintf( __('Check out the %s', 'sky-login-redirect'), '<a href="https://utopique.net/docs-category/login-redirect-pro/" target="_blank">plugin\'s documentation</a>.');
        $footer_text .= ' &bull; ' . sprintf( __( 'Check out the <a href="https://utopique.net/docs-category/login-redirect-pro/" target="_blank">%s</a>', 'sky-login-redirect' ), __( 'plugin\'s documentation', 'sky-login-redirect' ) );
        $sky_login_redirect_fs = sky_login_redirect_fs();
        if ( $sky_login_redirect_fs->is_not_paying() || $sky_login_redirect_fs->is_free_plan() ) {
            $footer_text .= ' &bull; ' . sprintf( '<a href="%s">' . __( 'Go premium', 'sky-login-redirect' ) . '</a>', $sky_login_redirect_fs->get_upgrade_url() );
        }
        return $footer_text;
    }
    
    /***
     * function sky_maybe_is_ssl
     *
     * return if ssl is enabled
     */
    function sky_maybe_is_ssl()
    {
        // cloudflare
        
        if ( !empty($_SERVER['HTTP_CF_VISITOR']) ) {
            $cfo = json_decode( $_SERVER['HTTP_CF_VISITOR'] );
            if ( isset( $cfo->scheme ) && 'https' === $cfo->scheme ) {
                return true;
            }
        }
        
        // other proxy
        if ( !empty($_SERVER['HTTP_X_FORWARDED_PROTO']) && 'https' === $_SERVER['HTTP_X_FORWARDED_PROTO'] ) {
            return true;
        }
        return ( function_exists( 'is_ssl' ) ? is_ssl() : false );
    }
    
    /***
     * function sky_get_referer
     *
     * Get referer via cookie if it is not set via wp_get_referer()
     */
    function sky_get_referer()
    {
        // check for a referer
        $referer = wp_get_referer();
        // cookie options array
        $cookie_options = [
            'expires'  => time() + HOUR_IN_SECONDS,
            'path'     => COOKIEPATH,
            'domain'   => COOKIE_DOMAIN,
            'secure'   => sky_maybe_is_ssl(),
            'httponly' => sky_maybe_is_ssl(),
            'samesite' => 'Strict',
        ];
        // if there is one, save it to a cookie
        
        if ( !empty($referer) ) {
            //setcookie( "referer_url", $referer, time()+3600 );
            setcookie( "referer_url", $referer, $cookie_options );
        } else {
            
            if ( isset( $_COOKIE['referer_url'] ) ) {
                // sweet, get it from the cookie
                $referer = $_COOKIE['referer_url'];
            } else {
                // get redir if it exists
                //$redirection = ( $_REQUEST['redirect_to'] ? esc_url_raw( $_REQUEST['redirect_to'] ) : '' );
                $redirection = ( isset( $_REQUEST['redirect_to'] ) ? esc_url_raw( $_REQUEST['redirect_to'] ) : '' );
                //$redirection = esc_url_raw( $_REQUEST['redirect_to'] );
                
                if ( !empty($redirection) ) {
                    $referer = $redirection;
                    //setcookie( "referer_url", $referer, time()+3600 );
                    setcookie( "referer_url", $referer, $cookie_options );
                }
            
            }
        
        }
        
        return $referer;
    }
    
    /*
     * Sky Login Redirect: redirection for login and logout
     */
    add_filter(
        'login_redirect',
        __NAMESPACE__ . '\\slr_redirection',
        20,
        3
    );
    add_filter(
        'logout_redirect',
        __NAMESPACE__ . '\\slr_redirection',
        20,
        3
    );
    function slr_redirection( $redirect_to, $requested_redirect_to, $user )
    {
        $slr_xselect_redirect = carbon_get_theme_option( 'slr_xlogin_logout' );
        // if a redirect_to parameter exists in the URL, honor it
        if ( isset( $_GET['redirect_to'] ) && !empty($_GET['redirect_to']) ) {
            return esc_url_raw( $_GET['redirect_to'] );
        }
        // do not activate this line, it breaks all rules
        //if( $requested_redirect_to) { return $requested_redirect_to; }
        // bypass wp-admin for login
        
        if ( preg_match( "/wp-admin/", $requested_redirect_to ) && current_filter() === 'login_redirect' ) {
            $redirect_to = esc_url_raw( $requested_redirect_to );
            return $redirect_to;
        }
        
        // in case no rule were created, redirect all users to homepage
        if ( empty($slr_xselect_redirect) ) {
            return esc_url_raw( home_url( '/' ) );
        }
        foreach ( $slr_xselect_redirect as $rule ) {
            // user
            
            if ( $rule['slr_xselect_redirect'] == 'user' ) {
                //$current_user = wp_get_current_user();
                $current_user = $user;
                if ( $current_user && is_object( $current_user ) && is_a( $current_user, 'WP_User' ) ) {
                    foreach ( $rule['slr_xuser'] as $usr ) {
                        $usrID = $usr;
                        $str = $usrID;
                        $start = strpos( $str, '(' );
                        $end = strpos( $str, ')', $start + 1 );
                        $length = $end - $start;
                        $result = substr( $str, $start + 1, $length - 1 );
                        $result = str_replace( 'ID=', '', $result );
                        $arr[$result] = array(
                            'name'   => $usrID,
                            'login'  => $rule['slr_xlogin_url'],
                            'logout' => $rule['slr_xlogout_url'],
                        );
                        foreach ( $arr as $key => $value ) {
                            
                            if ( $key == $current_user->ID ) {
                                $diff = str_replace( [ '_redirect', 'wp_ajax_nopriv_ajax' ], '', current_filter() );
                                // prior
                                
                                if ( $rule["slr_xselect_{$diff}"] == 'prior' ) {
                                    $link = slr_get_prior_url( $redirect_to, $requested_redirect_to, $user );
                                    return $link;
                                    break;
                                    // custom
                                } elseif ( $rule["slr_xselect_{$diff}"] == 'custom' ) {
                                    $link = $rule["slr_x{$diff}_url"];
                                    return $link;
                                    break;
                                    // WP defaults
                                } else {
                                    return admin_url( '/' );
                                    break;
                                }
                            
                            }
                        
                        }
                    }
                }
            }
            
            /* role */
            if ( $rule['slr_xselect_redirect'] == 'role' ) {
                foreach ( $rule['slr_xrole'] as $role ) {
                    //retrieve current user info
                    global  $wp_roles ;
                    //$current_user = wp_get_current_user();
                    $current_user = $user;
                    $roles = $wp_roles->roles;
                    //is there a user to check?
                    if ( isset( $current_user->roles ) && is_array( $current_user->roles ) ) {
                        
                        if ( in_array( $current_user->roles[0], $rule['slr_xrole'] ) ) {
                            //	$diff = str_replace( ['_redirect'], '', current_filter());
                            $diff = str_replace( [ '_redirect', 'wp_ajax_nopriv_ajax' ], '', current_filter() );
                            // prior
                            
                            if ( $rule["slr_xselect_{$diff}"] == 'prior' ) {
                                $link = slr_get_prior_url( $redirect_to, $requested_redirect_to, $user );
                                return $link;
                                break;
                                // custom
                            } elseif ( $rule["slr_xselect_{$diff}"] == 'custom' ) {
                                $link = $rule["slr_x{$diff}_url"];
                                return $link;
                                break;
                                // WP defaults
                            } else {
                                return admin_url( '/' );
                                break;
                            }
                        
                        }
                    
                    }
                }
            }
            // all
            
            if ( $rule['slr_xselect_redirect'] == 'all' ) {
                //$diff = str_replace( ['_redirect'], '', current_filter());
                $diff = str_replace( [ '_redirect', 'wp_ajax_nopriv_ajax' ], '', current_filter() );
                // prior
                
                if ( $rule["slr_xselect_{$diff}"] == 'prior' ) {
                    $link = slr_get_prior_url( $redirect_to, $requested_redirect_to, $user );
                    return $link;
                    break;
                    // custom
                } elseif ( $rule["slr_xselect_{$diff}"] == 'custom' ) {
                    $link = $rule["slr_x{$diff}_url"];
                    return $link;
                    break;
                    // WP defaults
                } else {
                    return admin_url( '/' );
                    break;
                }
            
            }
        
        }
    }
    
    function slr_get_prior_url( $redirect_to, $requested_redirect_to, $user )
    {
        $referer = sky_get_referer();
        // If the login page calls itself in $redirect_to, avoid the loop and redirect to the homepage.
        // This would happen when using password recovery and registration links.
        // It only concerns login, not logout (otherwise it breaks the logout referer)
        
        if ( preg_match( "/wp-login.php/", $redirect_to ) && current_filter() === 'login_redirect' ) {
            $redirect_to = esc_url_raw( home_url( '/' ) );
            return $redirect_to;
            //return ''; //this will blank out if user has clicked on register link or password recovery links before landing on the login page
        }
        
        // bypass wp-admin for login
        
        if ( preg_match( "/wp-admin/", $requested_redirect_to ) && current_filter() === 'login_redirect' ) {
            $redirect_to = esc_url_raw( $requested_redirect_to );
            return $redirect_to;
        }
        
        // logout: if we log out from wp-admin, redirect to homepage
        //if ( preg_match( "/wp-admin/", filter_var($_SERVER['HTTP_REFERER'], FILTER_VALIDATE_URL) ) && current_filter() === 'logout_redirect' ) :
        
        if ( preg_match( "/wp-admin/", filter_var( sky_get_referer(), FILTER_VALIDATE_URL ) ) && current_filter() === 'logout_redirect' ) {
            $redirect_to = esc_url_raw( home_url( '/' ) );
            return $redirect_to;
        }
        
        // If the referer is empty, go back to homepage.
        /* if( !$referer ) { $redirect_to = home_url('/'); return $redirect_to; } */
        // this bit is for when WP is installed in a subdirectory
        // if $referer equals the login page, get value from $redirect_to
        
        if ( preg_match( "/wp-login.php/", $referer ) && current_filter() === 'login_redirect' ) {
            $redirect_to = esc_url_raw( $redirect_to );
            return $redirect_to;
        }
        
        // Otherwise, go back to referring page.
        return $referer;
    }
    
    /*
     * Shortcode : [login-logout]
     */
    add_shortcode( 'login-logout', __NAMESPACE__ . '\\slr_login_logout_shortcode' );
    function slr_login_logout_shortcode()
    {
        
        if ( is_user_logged_in() ) {
            // user is logged in, therefore display the logout link
            // If you want to redirect the user to the same page after logout then use this line below instead
            return '<a class="logout-btn slr-lilo-shortcode" href="' . esc_url( wp_logout_url() ) . '">' . esc_html__( 'Logout', 'sky-login-redirect' ) . '</a>';
        } else {
            // user is logged out, therefore display the login link
            return '<a class="login-btn slr-lilo-shortcode" href="' . esc_url( wp_login_url() ) . '">' . esc_html__( 'Login', 'sky-login-redirect' ) . '</a>';
        }
    
    }
    
    // Execute shortcodes in widget_text
    add_filter( 'widget_text', 'do_shortcode' );
    /**
     * Custom Login URL
     **/
    add_filter(
        'login_url',
        __NAMESPACE__ . '\\slr_custom_login_page',
        10,
        3
    );
    function slr_custom_login_page( $url, $redirect, $force_reauth )
    {
        if ( is_admin() ) {
            return $url;
        }
        $page = carbonade( 'slr_custom_login_url' );
        
        if ( $page ) {
            // get slug
            $page = trailingslashit( basename( parse_url( $page, PHP_URL_PATH ) ) );
            //$page = trailingslashit( pathinfo( parse_url( $page, PHP_URL_PATH ), PATHINFO_BASENAME ) );
            $url = site_url( $page );
            if ( !empty($redirect) ) {
                $url = add_query_arg( 'redirect_to', urlencode( $redirect ), $url );
            }
            if ( $force_reauth ) {
                $url = add_query_arg( 'reauth', '1', $url );
            }
        }
        
        return $url;
    }
    
    /**
     * Custom Register URL
     **/
    /*
    			add_filter( 'register_url', __NAMESPACE__ . '\\slr_custom_register_page', 10, 1 );
    			function slr_custom_register_page( $url ) {
    			if( is_admin() ) {
    			return $url;
    		}
    		$page = carbonade( 'slr_custom_register_url' );
    		if ( $page ) :
    		// get slug
    		$page = trailingslashit( basename( parse_url( $page, PHP_URL_PATH ) ) );
    		//$page = trailingslashit( pathinfo( parse_url( $page, PHP_URL_PATH ), PATHINFO_BASENAME ) );
    		$url  = site_url( $page );
    	endif;
    	return $url;
    }
    */
    /**
     * Login customizer: logo LINK
     * Change logo link from wordpress.org to our domain
     **/
    add_filter(
        'login_headerurl',
        __NAMESPACE__ . '\\slr_login_logo_url',
        10,
        1
    );
    function slr_login_logo_url( $url )
    {
        $slr_logo_link = carbonade( 'slr_logo_link' );
        if ( $slr_logo_link == 'yes' ) {
            return home_url( '/' );
        }
    }
    
    /**
     * Login customizer: logo header text
     * Change logo header text
     **/
    add_filter( 'login_headertext', __NAMESPACE__ . '\\slr_login_logo_title' );
    function slr_login_logo_title()
    {
        $slr_logo_text = carbonade( 'slr_logo_text' );
        if ( $slr_logo_text == 'yes' ) {
            return get_bloginfo( 'name' );
        }
    }
    
    // Login preview
    add_action( 'admin_enqueue_scripts', __NAMESPACE__ . '\\slr_login_preview', 20 );
    function slr_login_preview( $hook )
    {
        if ( 'toplevel_page_sky-login-redirect' != $hook ) {
            return;
        }
        ?>
			<div id="slr-login-iframe" style="width:100%;border:0;display:none"><h3 style="margin-left: 1.4rem;font-weight: 400;"><?php 
        _e( 'Save your settings first to see changes', 'sky-login-redirect' );
        ?> <i class="las la-angle-double-down"></i></h3><iframe src="<?php 
        echo  home_url( '/wp-login.php' ) ;
        ?>" height="540px" width="100%" sandbox="allow-same-origin allow-scripts allow-popups"></iframe></div>
			<?php 
    }
    
    /**
     * Customizer
     */
    add_filter( 'login_head', __NAMESPACE__ . '\\slr_customizer_css', 50 );
    function slr_customizer_css()
    {
        $style = '';
        // back to blog
        if ( carbonade( 'slr_hide_backtoblog' ) == 'yes' ) {
            $style .= 'p#backtoblog a { display: none; }';
        }
        // privacy policy
        if ( carbonade( 'slr_hide_privacy_policy' ) == 'yes' ) {
            $style .= '.login .privacy-policy-page-link { display: none; }';
        }
        /* custom login logo */
        $slr_logo = carbonade( 'slr_custom_logo' );
        
        if ( !empty($slr_logo) ) {
            $imagedata = getimagesize( $slr_logo );
            // width : $imagedata[0];
            // height: $imagedata[1]
            $height = ( $imagedata && $imagedata[1] ? 'height: ' . $imagedata[1] . 'px;' : 'padding-bottom: 56.25%; height: 0;' );
            $style .= ".login h1 {\n\t\t\t\t\tposition: relative;\n\t\t\t\t\t{$height}\n\t\t\t\t\toverflow: hidden;\n\t\t\t\t}\n\t\t\t\t.login h1 a{\n\t\t\t\t\tbackground-image:none,url('{$slr_logo}') !important;\n\t\t\t\t\tbackground-size: auto;\n\t\t\t\t\tbackground-position: center top;\n\t\t\t\t\tbackground-repeat: no-repeat;\n\t\t\t\t\tcolor: #444;\n\t\t\t\t\tfont-size: 20px;\n\t\t\t\t\tfont-weight: 400;\n\t\t\t\t\tline-height: 1.3;\n\t\t\t\t\tmargin: 0 auto 25px;\n\t\t\t\t\tpadding: 0;\n\t\t\t\t\ttext-decoration: none;\n\t\t\t\t\ttext-indent: -9999px;\n\t\t\t\t\toutline: 0;\n\t\t\t\t\toverflow: hidden;\n\t\t\t\t\tdisplay: block;\n\t\t\t\t\tposition: absolute;\n\t\t\t\t\ttop: 0;\n\t\t\t\t\tleft: 0;\n\t\t\t\t\twidth: 100% !important;\n\t\t\t\t\theight: 100%;\n\t\t\t\t}";
        }
        
        /* page background color */
        $slr_page_background_color = carbonade( 'slr_page_background_color' );
        if ( !empty($slr_page_background_color) ) {
            $style .= "body.login { background: {$slr_page_background_color}; }";
        }
        /* page background image */
        $slr_page_background_image = carbonade( 'slr_page_background_image' );
        if ( !empty($slr_page_background_image) ) {
            $style .= "body.login {\n\t\t\t\t\tbackground-image: url('{$slr_page_background_image}');\n\t\t\t\t\tbackground-repeat: no-repeat;\n\t\t\t\t\tbackground-attachment: fixed;\n\t\t\t\t\tbackground-position: center;\n\t\t\t\t\tbackground-size:cover;\n\t\t\t\t}";
        }
        /* Login form background color */
        $slr_form_background_color = carbonade( 'slr_form_background_color' );
        if ( !empty($slr_form_background_color) ) {
            $style .= "body.login #loginform { background: {$slr_form_background_color}; }";
        }
        /* Login page background image */
        $slr_form_background_image = carbonade( 'slr_form_background_image' );
        if ( !empty($slr_form_background_image) ) {
            $style .= "body.login #loginform {\n\t\t\t\t\tbackground-image: url('{$slr_form_background_image}');\n\t\t\t\t\tbackground-repeat: no-repeat;\n\t\t\t\t\tb__ackground-attachment: fixed;\n\t\t\t\t\tbackground-position: center;\n\t\t\t\t}";
        }
        /* label colors */
        $slr_form_labels_color = carbonade( 'slr_form_labels_color' );
        if ( !empty($slr_form_labels_color) ) {
            $style .= "body.login div#login form#loginform label { color: {$slr_form_labels_color}; }";
        }
        /* nav links color */
        $slr_form_nav_color = carbonade( 'slr_form_nav_color' );
        if ( !empty($slr_form_nav_color) ) {
            $style .= "body.login #nav a { color: {$slr_form_nav_color}; }";
        }
        /* back to blog link */
        $slr_form_backtoblog_color = carbonade( 'slr_form_backtoblog_color' );
        if ( !empty($slr_form_backtoblog_color) ) {
            $style .= "body.login #backtoblog a { color: {$slr_form_backtoblog_color}; }";
        }
        /* privacy-policy-page-link */
        $slr_form_privacy_color = carbonade( 'slr_form_privacy_color' );
        if ( !empty($slr_form_privacy_color) ) {
            $style .= "body.login .privacy-policy-page-link a { color: {$slr_form_privacy_color}; }";
        }
        /* submit button */
        // active
        $submit_bg_color = carbonade( 'slr_form_submit_background_color' );
        $submit_text_color = carbonade( 'slr_form_submit_text_color' );
        $submit_border_color = carbonade( 'slr_form_submit_border_color' );
        $submit_border_radius = carbonade( 'slr_form_submit_radius' );
        $submit_border_width = carbonade( 'slr_form_submit_border_width' );
        $submit_border_radius = carbonade( 'slr_form_submit_radius' );
        $submit_bg_color = ( $submit_bg_color ? 'background:' . $submit_bg_color . ';' : '' );
        $submit_text_color = ( $submit_text_color ? 'color:' . $submit_text_color . ';' : '' );
        $submit_border_color = ( $submit_border_color ? 'border-color:' . $submit_border_color . ';' : '' );
        $submit_border_width = ( $submit_border_width ? 'border-width:' . $submit_border_width . 'px;' : '' );
        $submit_border_style = ( $submit_border_width ? 'border-style: solid' . ';' : '' );
        $submit_border_radius = ( $submit_border_radius ? 'border-radius:' . $submit_border_radius . 'px;' : '' );
        // hover
        $submit_bg_color_hover = carbonade( 'slr_form_submit_background_color_hover' );
        $submit_text_color_hover = carbonade( 'slr_form_submit_text_color_hover' );
        $submit_bg_color_hover = ( $submit_bg_color_hover ? 'background:' . $submit_bg_color_hover . ';' : '' );
        $submit_text_color_hover = ( $submit_text_color_hover ? 'color:' . $submit_text_color_hover . ';' : '' );
        // align
        $submit_align = carbonade( 'slr_form_submit_align' );
        
        if ( $submit_align == 'align-center' ) {
            $align = "display: grid; place-items: center;";
        } elseif ( $submit_align == 'align-left' ) {
            $align = "display: grid; place-items: start;";
        } elseif ( $submit_align == 'align-right' ) {
            $align = 'display: grid; place-items: end;';
        } else {
            $align = '';
        }
        
        if ( $align ) {
            $style .= "body.login #login form p.submit { {$align} }";
        }
        // size
        $submit_size = carbonade( 'slr_form_submit_size' );
        
        if ( $submit_size == 'custom' ) {
            $width = carbonade( 'slr_form_submit_size_width' );
            $height = carbonade( 'slr_form_submit_size_height' );
            $width = ( $width ? 'width:' . $width . 'px;' : '' );
            $height = ( $height ? 'height:' . $height . 'px;' : '' );
        } elseif ( $submit_size == 'full-width' ) {
            $width = 'width:100%;';
            $height = 'height:100%;';
        } else {
            $width = '';
            $height = '';
        }
        
        if ( $submit_bg_color || $submit_text_color || $submit_border_color || $submit_border_width && $submit_border_style || $submit_border_radius || $height || $width ) {
            $style .= "body.login #wp-submit {\n\t\t\t\t\t\t\t\t{$submit_bg_color} {$submit_text_color}\n\t\t\t\t\t\t\t\t{$submit_border_color} {$submit_border_width} {$submit_border_style} {$submit_border_radius}\n\t\t\t\t\t\t\t\t{$height} {$width} }";
        }
        if ( $submit_bg_color_hover || $submit_text_color_hover ) {
            $style .= "body.login #wp-submit:hover { {$submit_bg_color_hover} {$submit_text_color_hover} }";
        }
        // echo!
        if ( !empty($style) ) {
            echo  "<style>{$style}</style>" ;
        }
    }
    
    /**
     * Hide "Remember Me" checkbox
     */
    add_filter( 'login_head', __NAMESPACE__ . '\\slr_hide_remember_me', 50 );
    add_action( 'woocommerce_login_form_start', __NAMESPACE__ . '\\slr_hide_remember_me', 10 );
    function slr_hide_remember_me()
    {
        $style = '';
        $slr_hide_remember_me = carbonade( 'slr_hide_remember_me' );
        
        if ( $slr_hide_remember_me == 'yes' ) {
            $style .= 'p.forgetmenot { display: none; }';
            // WordPress
            $style .= 'label.woocommerce-form__label.woocommerce-form__label-for-checkbox.woocommerce-form-login__rememberme { display: none; }';
            // WooCommerce
        }
        
        // echo!
        if ( !empty($style) ) {
            echo  "<style>{$style}</style>" ;
        }
    }
    
    // EDD
    add_filter(
        'edd_login_form',
        __NAMESPACE__ . '\\slr_edd_hide_remember_me',
        10,
        1
    );
    function slr_edd_hide_remember_me( $var )
    {
        $style = '';
        $slr_hide_remember_me = carbonade( 'slr_hide_remember_me' );
        
        if ( $slr_hide_remember_me == 'yes' ) {
            $style .= 'p.edd-login-remember { display: none; }';
            // EDD
        }
        
        // echo!
        if ( !empty($style) ) {
            return $var . "<style>{$style}</style>";
        }
        // default return
        return $var;
    }
    
    /**
     * Check "Remember Me" checkbox
     */
    add_action( 'login_footer', __NAMESPACE__ . '\\slr_check_remember_me', 10 );
    add_action( 'woocommerce_login_form_end', __NAMESPACE__ . '\\slr_check_remember_me', 10 );
    function slr_check_remember_me()
    {
        $slr_check_remember_me = carbonade( 'slr_check_remember_me' );
        if ( $slr_check_remember_me == 'yes' ) {
            echo  "<script>const rememberme = document.getElementById('rememberme'); if(rememberme){ rememberme.checked = true; }</script>" ;
        }
    }
    
    // EDD
    add_filter(
        'edd_login_form',
        __NAMESPACE__ . '\\slr_edd_check_remember_me',
        10,
        1
    );
    function slr_edd_check_remember_me( $var )
    {
        $slr_check_remember_me = carbonade( 'slr_check_remember_me' );
        if ( $slr_check_remember_me == 'yes' ) {
            $var .= "<script>const rememberme = document.getElementById('rememberme'); if(rememberme){ rememberme.checked = true; }</script>";
        }
        // default return
        return $var;
    }
    
    // OPTIONS
    add_action( 'carbon_fields_theme_options_container_saved', __NAMESPACE__ . '\\slr_get_cached_options' );
    function slr_get_cached_options( $opt )
    {
        global  $wpdb ;
        static  $opt = array() ;
        // get all the needed options with one query
        $options = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}options WHERE option_name LIKE '_slr_%'", ARRAY_A );
        // also maybe store the options in a transient?
        foreach ( $options as $option ) {
            unset( $option['option_id'] );
            unset( $option['autoload'] );
            $key = $option['option_name'];
            $opt[$key] = $option['option_value'];
        }
        // transient
        set_transient( 'sky_login_redirect', $opt, 0 );
        // 0 so that's never erased
        // option as backup
        update_option( 'sky_login_redirect', $opt );
        return $opt;
    }
    
    function carbonade( $key, $echo = 'false' )
    {
        $transient = get_transient( 'sky_login_redirect' );
        if ( false === $transient ) {
            // this seems to cause issues
            //return carbon_get_theme_option( $key ) ?? '';
            $transient = get_option( 'sky_login_redirect' );
        }
        $key = '_' . $key;
        
        if ( $echo === true ) {
            echo  $transient[$key] ?? '' ;
        } else {
            return $transient[$key] ?? '';
        }
    
    }
    
    // Enqueue scripts
    add_action( 'admin_enqueue_scripts', __NAMESPACE__ . '\\slr_add_scripts' );
    function slr_add_scripts( $hook )
    {
        wp_add_inline_style( 'mediaelement', ".toplevel_page_sky-login-redirect .wp-menu-image img {\n\t\t\t\t\t\t\t\t\tf__ilter: invert(48%) sepia(79%) saturate(2476%) hue-rotate(86deg) brightness(118%) contrast(119%);\n\t\t\t\t\t\t\t\t\tline-height: 1;\n\t\t\t\t\t\t\t\t\tspeak: none;\n\t\t\t\t\t\t\t\t\ttext-decoration: inherit;\n\t\t\t\t\t\t\t\t\ttext-transform: none;\n\t\t\t\t\t\t\t\t\ttext-rendering: auto;\n\t\t\t\t\t\t\t\t\t-webkit-font-smoothing: antialiased;\n\t\t\t\t\t\t\t\t\t-moz-osx-font-smoothing: grayscale;\n\t\t\t\t\t\t\t\t\twidth: 22px;\n\t\t\t\t\t\t\t\t\theight: 24px;\n\t\t\t\t\t\t\t\t\tfont-size: 26px;\n\t\t\t\t\t\t\t\t\tvertical-align: top;\n\t\t\t\t\t\t\t\t\ttext-align: center;\n\t\t\t\t\t\t\t\t\tpadding: 6px 0 !important;\n\t\t\t\t\t\t\t\t\ttransition: all .1s ease-in-out;\n\t\t\t\t\t\t\t\t}\n\n\t\t\t\t\t\t\t\ta.toplevel_page_sky-login-redirect:hover img {\n\t\t\t\t\t\t\t\t\tbackface-visibility: hidden;\n\t\t\t\t\t\t\t\t\tperspective: 1000px;\n\t\t\t\t\t\t\t\t\ttransform: rotate(180deg);\n\t\t\t\t\t\t\t\t\ttransition: all 1s ease-in-out;\n\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t" );
        $array = [
            'toplevel_page_sky-login-redirect',
            'login-redirect_page_sky-login-redirect-account',
            'login-redirect_page_sky-login-redirect-contact',
            'login-redirect_page_sky-login-redirect-pricing'
        ];
        
        if ( in_array( $hook, $array ) ) {
            wp_enqueue_style(
                'utopique-elements',
                plugins_url( 'lib/css/elements.css', __FILE__ ),
                false,
                SLR_VERSION,
                'all'
            );
            wp_enqueue_style(
                'slr',
                plugins_url( 'lib/css/slr.css', __FILE__ ),
                false,
                SLR_VERSION,
                'all'
            );
            wp_enqueue_script(
                'slr-js',
                plugins_url( 'lib/js/slr.js', __FILE__ ),
                [ 'jquery' ],
                SLR_VERSION,
                true
            );
            wp_localize_script( 'slr-js', 'SLR', array(
                'upgrade_url'      => sky_login_redirect_fs()->get_upgrade_url(),
                'pro_feature'      => __( 'unlock with Pro version', 'sky-login-redirect' ),
                'business_feature' => __( 'unlock with Business version', 'sky-login-redirect' ),
            ) );
            // Codemirror editor
            
            if ( $hook === $array[0] ) {
                $cm_css['codeEditor'] = wp_enqueue_code_editor( [
                    'type' => 'text/css',
                ] );
                wp_localize_script( 'jquery', 'cm_css', $cm_css );
                $cm_js['codeEditor'] = wp_enqueue_code_editor( [
                    'type' => 'text/html',
                ] );
                wp_localize_script( 'jquery', 'cm_js', $cm_js );
                wp_enqueue_script( 'wp-theme-plugin-editor' );
                wp_enqueue_style( 'wp-codemirror' );
            }
            
            // remove WP emoji on our pages
            remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
            remove_action( 'admin_print_styles', 'print_emoji_styles' );
            return;
        }
    
    }

}

// FS endif